==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTRCMFUNCTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EQUIPMENTRCMFUNCTIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTRCMFUNCTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTRCMFUNCTIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTRCMFUNCTIONID_Type", propOrder = {
    "equipmentrcmfunctioncode",
    "description"
})
public class EQUIPMENTRCMFUNCTIONID_Type {

    @XmlElement(name = "EQUIPMENTRCMFUNCTIONCODE")
    protected String equipmentrcmfunctioncode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the equipmentrcmfunctioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTRCMFUNCTIONCODE() {
        return equipmentrcmfunctioncode;
    }

    /**
     * Sets the value of the equipmentrcmfunctioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTRCMFUNCTIONCODE(String value) {
        this.equipmentrcmfunctioncode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTRCMFUNCTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EQUIPMENTRCMFUNCTIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTRCMFUNCTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTRCMFUNCTIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTRCMFUNCTIONID_Type", propOrder = {
    "equipmentrcmfunctioncode",
    "description"
})
public class EQUIPMENTRCMFUNCTIONID_Type {

    @XmlElement(name = "EQUIPMENTRCMFUNCTIONCODE")
    protected String equipmentrcmfunctioncode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété equipmentrcmfunctioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTRCMFUNCTIONCODE() {
        return equipmentrcmfunctioncode;
    }

    /**
     * Définit la valeur de la propriété equipmentrcmfunctioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTRCMFUNCTIONCODE(String value) {
        this.equipmentrcmfunctioncode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
